package com.jiuqi.util;

package .tmp;

import com.jiuqi.util.chinese.ChineseDouble;
import com.jiuqi.util.chinese.ChineseInt;
import com.jiuqi.util.chinese.NoValidCharException;
import com.jiuqi.util.chinese.NotValidChineseNumberException;
import java.text.FieldPosition;
import java.text.NumberFormat;
import java.text.ParsePosition;

public class ChineseNumberFormat extends NumberFormat {
  private boolean useCapital;
  
  private int decimal;
  
  public ChineseNumberFormat() {
    this.useCapital = false;
    this.decimal = 2;
  }
  
  public ChineseNumberFormat(boolean useCapital) {
    this.useCapital = useCapital;
    this.decimal = 2;
  }
  
  public ChineseNumberFormat(boolean useCapital, int decimal) {
    this.useCapital = useCapital;
    this.decimal = decimal;
  }
  
  public boolean getUseCapital() {
    return this.useCapital;
  }
  
  public void setUseCapital(boolean value) {
    this.useCapital = value;
  }
  
  public int getDecimal() {
    return this.decimal;
  }
  
  public void setDecimal(int value) {
    this.decimal = value;
  }
  
  public Number parse(String source, ParsePosition parsePosition) {
    if (source == null)
      return null; 
    if (source.indexOf("点") != -1 || source.indexOf("分之") != -1)
      try {
        return new Double(ChineseDouble.valueOf(source));
      } catch (NotValidChineseNumberException e) {
        e.printStackTrace();
        return null;
      } catch (NoValidCharException e) {
        e.printStackTrace();
        return null;
      }  
    try {
      return new Long(ChineseInt.valueOf(source));
    } catch (NotValidChineseNumberException e) {
      e.printStackTrace();
      return null;
    } catch (NoValidCharException e) {
      e.printStackTrace();
      return null;
    } 
  }
  
  public StringBuffer format(double number, StringBuffer toAppendTo, FieldPosition pos) {
    String value = ChineseDouble.parseToChinese(String.valueOf(number), this.decimal, false, this.useCapital);
    toAppendTo.append(value);
    return toAppendTo;
  }
  
  public StringBuffer format(long number, StringBuffer toAppendTo, FieldPosition pos) {
    String value = ChineseInt.parseToChinese(String.valueOf(number), false, this.useCapital);
    toAppendTo.append(value);
    return toAppendTo;
  }
  
  private static String[] chDigitUnits = new String[] { 
      "", "十", "百", "千", "万", "十万", "百万", "千万", "亿", "十亿", 
      "百亿", "千亿", "万亿", "兆" };
  
  public static String toChineseDigitUnit(double unitValue) {
    return toChineseDigitUnit((long)Math.rint(unitValue));
  }
  
  public static String toChineseDigitUnit(long unitValue) {
    int factor = 0;
    while (unitValue >= 10L) {
      unitValue /= 10L;
      factor++;
    } 
    return (factor >= chDigitUnits.length) ? null : chDigitUnits[factor];
  }
}
